@@ -1,16 +1,14 @@
 # server_simple.py
-from __future__ import annotations
-
 from aiohttp import web
 
 
-async def handle(request):
+async def handle(request: web.Request) -> web.StreamResponse:
     name = request.match_info.get("name", "Anonymous")
     text = "Hello, " + name
     return web.Response(text=text)
 
 
-async def wshandle(request):
+async def wshandle(request: web.Request) -> web.StreamResponse:
     ws = web.WebSocketResponse()
     await ws.prepare(request)
 
