@@ -65,6 +65,21 @@ DIST_ATTRS = {
             {"include_msvcr": IS_WINDOWS},
             id="include-msvcr=true",
         ),
+        pytest.param(
+            {"include_msvcr_version": "15"},
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "15"},
+            id="include-msvcr-version=15",
+        ),
+        pytest.param(
+            {"include_msvcr_version": "16"},
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "16"},
+            id="include-msvcr-version=16",
+        ),
+        pytest.param(
+            {"include_msvcr_version": "17"},
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "17"},
+            id="include-msvcr-version=17",
+        ),
         pytest.param(
             {"replace_paths": [("*", "")]},
             {"replace_paths": [("*", "")]},
@@ -346,6 +361,21 @@ def test_build_exe_finalize_options_raises(
             {"include_msvcr": IS_WINDOWS},
             id="--include-msvcr",
         ),
+        pytest.param(
+            ["--include-msvcr-version=15"],
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "15"},
+            id="--include-msvcr-version=15",
+        ),
+        pytest.param(
+            ["--include-msvcr-version=16"],
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "16"},
+            id="--include-msvcr-version=16",
+        ),
+        pytest.param(
+            ["--include-msvcr-version=17"],
+            {"include_msvcr": IS_WINDOWS, "include_msvcr_version": "17"},
+            id="--include-msvcr-version=17",
+        ),
     ],
 )
 def test_build_exe_script_args(
